@@ -49,22 +49,8 @@ def test_hive():
         'auth': 'NOSASL'
     }
     hive = Hive(hive_connection)
-    hive_sql="""
-        select shr_staff_no
-      from dwd.dwd_other_billing_power_list t
-      join (-- 近1个月有医疗收入开单的医生
-    select nvl(sf.ehr_user_name,t.ehr_user_name) as shr_code
-      from ads.ads_zm_doctor_comy_anay t
-      left join dim.dim_staff sf on t.create_userid = sf.user_id
-     where t.dtype = 'day'
-       and t.dt >= date_sub(current_date(),30) -- 近1个月
-       and t.medical_amt > 0  -- 有医疗收入
-         group by nvl(sf.ehr_user_name,t.ehr_user_name)
-      ) dc on t.shr_staff_no = dc.shr_code
-     where t.role_name = '开单权限'
-       and t.vet_id_number is not null   -- 有执兽证
-       and t.is_beian = '否'             -- 未进行执业兽医备案
-     group by shr_staff_no
+    hive_sql = """
+    select count(*) from dim.dim_clinic
     """
     rows = hive.query(hive_sql)
     print(rows)
